
/* This dofile helps you link the two datasets: VHLSS 2002 and VHLSS 2004. What you will get when running
the program is a panel dataset with some important variables such as household weights individual 
weights.

To adapt this program in order to run it on your machine, please make the following changes:
	1. Chang directories where data are put.

Author: Le Dang Trung
Organization: Centre for Analysis and Forecast - VASS
Last modification: 11:24 AM 3/22/2006
*******************************************************************************************************/

#delimit;
clear;
set mem 50m;
set more off;

local data04 "D:\Data\Household Surveys\VHLSS2\Data\HH data\";						// Change directory here
local data02 "D:\Data\Household Surveys\VHLSS1\Data\hhold\";						// Change directory here
local datatemp "C:\Temp\";																		// Change directory here
*******************************************************************************************************;
*******************************************************************************************************;
****************** 					GET HHID FROM VHLSS 2002 DATA								*******************;
*******************************************************************************************************;
use "`data02'hhexpe02.dta", clear;
gen double hhid02=hoso + (10^5)*xa;
format hhid02 %12.0f;

keep hhid02 urban02 wt30 hhsizewt;
rename wt30 hhwt02;
rename hhsizewt indwt02;
sort hhid02;
save "`datatemp'VHLSS02hhid.dta", replace;										// To be merged with VHLSS04hhid

*******************************************************************************************************;
****************** 					GET HHID FROM VHLSS 2004 DATA								*******************;
*******************************************************************************************************;
* Get household and individual weights;
use "`data04'hhexpe04.dta", clear;
gen double hhid04=hoso + (10^2)*diaban + (10^5)*xa + (10^7)*huyen + (10^9)*tinh;
format hhid04 %12.0f;

keep hhid04 hhwt hhszwt urban04;
rename hhwt hhwt04;
rename hhszwt indwt04;

sort hhid04;
save "`datatemp'VHLSS04wt.dta", replace;											// To be merged with VHLSS04hhid

* Get hhid02 and hhid04;
use "`data04'ho1.dta", clear;
gen double hhid04=hoso + (10^2)*diaban + (10^5)*xa + (10^7)*huyen + (10^9)*tinh;
format hhid04 %12.0f;

keep if quyen==1;
replace xa02=xa02+huyen02*100+tinh02*10000;			// This recoding was provided by GSO without detailed
replace hoso02=hoso02+100 if quy02==3|quy02==4;		// explanation.
replace hoso02=hoso02+diaban02*1000;

gen double hhid02=hoso02 + (10^5)*xa02;
format hhid02 %12.0f;

keep hhid04 hhid02;
sort hhid04;
merge hhid04 using "`datatemp'VHLSS04wt.dta";
tab _merge;
keep if _merge==3;
drop _merge;

sort hhid02;
merge hhid02 using "`datatemp'VHLSS02hhid.dta";
tab _merge;
keep if _merge==3;
drop _merge;
aorder;

*******************************************************************************************************;
****************** 									LABEL VARIABLES								*******************;
*******************************************************************************************************;
label var hhid02 "Household identifier in VHLSS 2002";
label var hhid04 "Household identifier in VHLSS 2004";
label var hhwt02 "Household weights in VHLSS 2002";
label var hhwt04 "Household weights in VHLSS 2004";
label var indwt02 "Individual weights in VHLSS 2002";
label var indwt04 "Individual weights in VHLSS 2004";
label var urban02 "Location of household in VHLSS 2002";
label values urban02 urban02;
label define urban02 1 "Urban" 2 "Rural";
label var urban04 "Location of household in VHLSS 2004";
label values urban04 urban04;
label define urban04 1 "Urban" 2 "Rural";

*******************************************************************************************************;
****************** 									SAVE THE PANEL SET							*******************;
*******************************************************************************************************;
save "`datatemp'VHLSS02_04_panel.dta";